@@ -18,6 +18,15 @@ class SubRipFile(UserList, object):
     SubRip file descriptor.
 
     Provide a pure Python mapping on all metadata.
+
+    SubRipFile(items, eol, path, encoding)
+
+    items -> list of SubRipItem. Default to [].
+    eol -> str: end of line character. Default to linesep used in opened file
+        if any else to os.linesep.
+    path -> str: path where file will be saved. To open an existant file see
+        SubRipFile.open.
+    encoding -> str: encoding used at file save. Default to utf-8.
     """
     ERROR_PASS = 0
     ERROR_LOG = 1
@@ -71,10 +80,11 @@ class SubRipFile(UserList, object):
                 string_buffer.seek(0)
                 source = unicode(string_buffer.read(), new_file.encoding)
                 try:
-                    new_item = SubRipItem.from_string(source)
-                    new_file.append(new_item)
-                except InvalidItem, error:
-                    cls._handle_error(error, error_handling, path, index)
+                    try:
+                        new_item = SubRipItem.from_string(source)
+                        new_file.append(new_item)
+                    except InvalidItem, error:
+                        cls._handle_error(error, error_handling, path, index)
                 finally:
                     string_buffer.truncate(0)
 
@@ -138,12 +148,12 @@ class SubRipFile(UserList, object):
         """
         path = path or self.path
         encoding = encoding or self.encoding
-        eol = eol or self.eol
+        output_eol = eol or self.eol
 
         save_file = open(path, 'w+')
         for item in self:
             string_repr = unicode(item)
-            if eol != self.eol:
-                string_repr = string_repr.replace(self.eol, eol)
+            if output_eol != '\n':
+                string_repr = string_repr.replace('\n', output_eol)
             save_file.write(string_repr.encode(encoding))
         save_file.close()
