@@ -1,11 +1,15 @@
 # -*- coding: utf-8 -*-
+"""
+SubRip's time format parser: HH:MM:SS,mmm
+"""
 import re
 from datetime import time
 
-from srtexc import InvalidTimeString
+from pysrt.srtexc import InvalidTimeString
 
 
 class Comparable(object):
+    # pylint: disable-msg=E0211,R0903
     """
     Some builtin types like datetime.time don't use the __cmp__ interface.
     This class map "rich comparison" methods to __cmp__
@@ -22,9 +26,11 @@ class Comparable(object):
     __gt__ = __build_comparator(1)
     __ge__ = __build_comparator(0, 1)
 
+    del __build_comparator
+
 
 class TimeItemDescriptor(object):
-
+    # pylint: disable-msg=R0903
     def __init__(self, ratio, super_ratio=0):
         self.ratio = int(ratio)
         self.super_ratio = int(super_ratio)
@@ -64,6 +70,7 @@ class SubRipTime(Comparable):
 
         All arguments are optional and have a default value of 0.
         """
+        super(SubRipTime, self).__init__()
         self.ordinal = hours * self.HOURS_RATIO \
                      + minutes * self.MINUTES_RATIO \
                      + seconds * self.SECONDS_RATIO \
@@ -97,6 +104,15 @@ class SubRipTime(Comparable):
 
     @classmethod
     def _coerce(cls, other):
+        """
+        Coerce many types to SubRipTime instance.
+        Supported types:
+          - str/unicode
+          - int/long
+          - datetime.time
+          - any iterable
+          - dict
+        """
         if isinstance(other, SubRipTime):
             return other
         elif isinstance(other, basestring):
@@ -126,10 +142,17 @@ class SubRipTime(Comparable):
 
     @classmethod
     def from_ordinal(cls, ordinal):
+        """
+        int -> SubRipTime corresponding to a total count of milliseconds
+        """
         return cls(milliseconds=int(ordinal))
 
     @classmethod
     def from_string(cls, source):
+        """
+        str/unicode(HH:MM:SS,mmm) -> SubRipTime corresponding to serial
+        raise InvalidTimeString
+        """
         match = cls.RE_TIME.match(source)
         if not match:
             raise InvalidTimeString
@@ -137,10 +160,16 @@ class SubRipTime(Comparable):
         return cls(**items)
 
     @classmethod
-    def from_time(cls, time):
-        return cls(hours=time.hour, minutes=time.minute, seconds=time.second,
-                   milliseconds=time.microsecond / 1000)
+    def from_time(cls, source):
+        """
+        datetime.time -> SubRipTime corresponding to time object
+        """
+        return cls(hours=source.hour, minutes=source.minute,
+            seconds=source.second, milliseconds=source.microsecond / 1000)
 
     def to_time(self):
+        """
+        Convert SubRipTime instance into a pure datetime.time object
+        """
         return time(self.hours, self.minutes, self.seconds,
                     self.milliseconds * 1000)
